==> moodle-1.5-mysql.tgz: moodle/lang/nl/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.5 ALPHA (2005051500)


$string['allowresubmit'] = 'Sta herhaald insturen toe';
$string['assignmentdetails'] = 'De details van de opdracht';
$string['assignmentmail'] = '$a->teacher heeft feedback gepost voor je bijdrage aan de opdracht \'$a->assignment\'
Hij is toegevoegd aan je ingestuurde opdracht:
$a->url';
$string['assignmentmailhtml'] = '$a->teacher heeft feedback gepost voor je bijdrage aan de opdracht \'<i>$a->assignment</i>\'<br /><br />
Hij is toegevoegd aan je ingestuurde <a href=\"$a->url\">opdracht</a>.';
$string['assignmentname'] = 'Naam van de opdracht';
$string['assignmenttype'] = 'Soort opdracht';
$string['availabledate'] = 'Beschikbaar vanaf';
$string['comment'] = 'Commentaar';
$string['commentinline'] = 'Commentaar invoegen';
$string['configmaxbytes'] = 'Standaard maximumgrootte voor alle opdrachten op de site (afhankelijk van vaklimieten en andere lokale instellingen)';
$string['description'] = 'Beschrijving  ';
$string['duedate'] = 'Uiterste inleverdatum';
$string['duedateno'] = 'Geen uiterste inleverdatum';
$string['early'] = '$a vroeg';
$string['editmysubmission'] = 'Bewerk mijn inzending';
$string['emailteachermail'] = '$a->username heeft de inzending voor opdracht $a->assignment aangepast.

Je kunt ze hier vinden:

$a->url';
$string['emailteachermailhtml'] = '$a->username heeft de inzending voor opdracht <i>$a->assignment</i> aangepast.<br /><br />
Je kunt ze hier vinden:
Je kunt het <a href=\"$a->url\"> nakijken op de website</a>.';
$string['emailteachers'] = 'Stuur een e-mail als waarschuwing naar de leraren';
$string['emptysubmission'] = 'Je hebt nog niets ingestuurd';
$string['existingfiledeleted'] = 'Het vorige bestand is verwijderd: $a';
$string['failedupdatefeedback'] = 'Het updaten van de feedback op de ingestuurde opdracht van gebruiker $a is niet gelukt';
$string['feedback'] = 'Feedback';
$string['feedbackfromteacher'] = 'Feedback van de $a';
$string['feedbackupdated'] = 'De feedback op ingestuurde opdrachten is voor $a mensen bijgewerkt';
$string['helpoffline'] = '<p>Dit is nuttig wanneer de opdracht buiten Moodle gebeurt. Dat kan ergens anders op het web zijn of face-to-face.</p><p>Leerlingen kunnen een beschrijving van de opdracht zien, maar kunnen geen bestanden uploaden. Je kunt gewoon cijfers geven en leerlingen kunnen die dan inkijken.</p>';
$string['helponline'] = '<p>Dit type opdracht vraagt gebruikers een tekst te bewerken. Leraren kunnen die dan on line beoordelen en zelfs verbeteren en wijzigingen aanbrengen in de tekst.</p>
<p>(Als je vertrouwd bent met oudere versies van Moodle, dan lijkt dit type opdracht erg op de vroegere logboek module.)</p>';
$string['helpuploadsingle'] = '<p>Dit type opdracht laat elke deelnemer toe om n bestand te uploaden, gelijk welk bestandstype.</p><p>Dit kan een bestand zijn van een tekstverwerker, een afbeelding, een website in een zip-bestand of gelijk welk bestandstype dat je je leerlingen vraagt te maken</p>';
$string['late'] = '$a laat';
$string['maximumgrade'] = 'Maximale cijfer';
$string['maximumsize'] = 'Maximale grootte  ';
$string['modulename'] = 'Opdracht';
$string['modulenameplural'] = 'Opdrachten';
$string['newsubmissions'] = 'Ingestuurde opdrachten';
$string['noassignments'] = 'Er zijn nog geen opdrachten';
$string['noattempts'] = 'Er heeft nog niemand zijn opdracht ingestuurd';
$string['notgradedyet'] = 'Nog niet beoordeeld';
$string['notsubmittedyet'] = 'Nog niet ingestuurd';
$string['overwritewarning'] = 'Waarschuwing: als je opnieuw een opdracht instuurt OVERSCHRIJFT deze de huidige ingestuurde opdracht';
$string['preventlate'] = 'Blokkeer te laat insturen';
$string['saveallfeedback'] = 'Bewaar al mijn feedback';
$string['submission'] = 'Ingestuurde opdracht';
$string['submissionfeedback'] = 'Feedback op de ingestuurde opdracht';
$string['submissions'] = 'Ingestuurde opdrachten';
$string['submissionsaved'] = 'Je wijzigingen zijn bewaard';
$string['submitassignment'] = 'Stuur je opdracht in door dit formulier in te vullen';
$string['submitted'] = 'Ingestuurd';
$string['typeoffline'] = 'Off line activiteit';
$string['typeonline'] = 'On line activiteit';
$string['typeuploadsingle'] = 'Upload een bestand';
$string['uploadbadname'] = 'In deze bestandsnaam staan rare tekens, het bestand kon daardoor niet worden gepload';
$string['uploadedfiles'] = 'Ingestuurde bestanden';
$string['uploaderror'] = 'Er is een fout geconstateerd tijdens het opslaan van het bestand op de server';
$string['uploadfailnoupdate'] = 'Het bestand werd prima gepload, maar je bijdrage kon niet worden bijgewerkt!';
$string['uploadfiletoobig'] = 'Helaas is dat bestand te groot (de toegestane grootte is $a bytes)';
$string['uploadnofilefound'] = 'Er werd geen bestand gevonden - weet je zeker dat je er n geselecteerd had om te uploaden?';
$string['uploadnotregistered'] = '\'$a\' werd prima gepload, maar je bijdrage werd niet verwerkt!';
$string['uploadsuccess'] = '\'$a\' met succes gepload  ';
$string['viewfeedback'] = 'Bekijk de cijfers en feedback voor de opdrachten';
$string['viewsubmissions'] = 'Bekijk $a ingestuurde opdrachten';
$string['yoursubmission'] = 'Jouw ingestuurde opdracht';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/nl/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.6 development (2005060201)


$string['allowresubmit'] = 'Sta herhaald insturen toe';
$string['assignmentdetails'] = 'De details van de opdracht';
$string['assignmentmail'] = '$a->teacher heeft feedback gepost voor je bijdrage aan de opdracht \'$a->assignment\'
Hij is toegevoegd aan je ingestuurde opdracht:
$a->url';
$string['assignmentmailhtml'] = '$a->teacher heeft feedback gepost voor je bijdrage aan de opdracht \'<i>$a->assignment</i>\'<br /><br />
Hij is toegevoegd aan je ingestuurde <a href=\"$a->url\">opdracht</a>.';
$string['assignmentname'] = 'Naam van de opdracht';
$string['assignmenttype'] = 'Soort opdracht';
$string['availabledate'] = 'Beschikbaar vanaf';
$string['comment'] = 'Commentaar';
$string['commentinline'] = 'Commentaar invoegen';
$string['configmaxbytes'] = 'Standaard maximumgrootte voor alle opdrachten op de site (afhankelijk de limiet van de cursus en van andere lokale instellingen)';
$string['description'] = 'Beschrijving  ';
$string['duedate'] = 'Uiterste inleverdatum';
$string['duedateno'] = 'Geen uiterste inleverdatum';
$string['early'] = '$a vroeg';
$string['editmysubmission'] = 'Bewerk mijn inzending';
$string['emailteachermail'] = '$a->username heeft de inzending voor opdracht $a->assignment aangepast.

Je kunt ze hier vinden:

$a->url';
$string['emailteachermailhtml'] = '$a->username heeft de inzending voor opdracht <i>$a->assignment</i> aangepast.<br /><br />
Je kunt ze hier vinden:
Je kunt het <a href=\"$a->url\"> nakijken op de website</a>.';
$string['emailteachers'] = 'Stuur een e-mail als waarschuwing naar de leraren';
$string['emptysubmission'] = 'Je hebt nog niets ingestuurd';
$string['existingfiledeleted'] = 'Het vorige bestand is verwijderd: $a';
$string['failedupdatefeedback'] = 'Het updaten van de feedback op de ingestuurde opdracht van gebruiker $a is niet gelukt';
$string['feedback'] = 'Feedback';
$string['feedbackfromteacher'] = 'Feedback van de $a';
$string['feedbackupdated'] = 'De feedback op ingestuurde opdrachten is voor $a mensen bijgewerkt';
$string['guestnoupload'] = 'Sorry, gasten mogen geen bestanden uploaden';
$string['helpoffline'] = '<p>Dit is nuttig wanneer de opdracht buiten Moodle gebeurt. Dat kan ergens anders op het web zijn of face-to-face.</p><p>Leerlingen kunnen een beschrijving van de opdracht zien, maar kunnen geen bestanden uploaden. Je kunt gewoon cijfers geven en leerlingen kunnen die dan inkijken.</p>';
$string['helponline'] = '<p>Dit type opdracht vraagt gebruikers een tekst te bewerken. Leraren kunnen die dan on line beoordelen en zelfs verbeteren en wijzigingen aanbrengen in de tekst.</p>
<p>(Als je vertrouwd bent met oudere versies van Moodle, dan lijkt dit type opdracht erg op de vroegere logboek module.)</p>';
$string['helpuploadsingle'] = '<p>Dit type opdracht laat elke deelnemer toe om n bestand te uploaden, gelijk welk bestandstype.</p><p>Dit kan een bestand zijn van een tekstverwerker, een afbeelding, een website in een zip-bestand of gelijk welk bestandstype dat je je leerlingen vraagt te maken</p>';
$string['late'] = '$a laat';
$string['maximumgrade'] = 'Maximale cijfer';
$string['maximumsize'] = 'Maximale grootte  ';
$string['modulename'] = 'Opdracht';
$string['modulenameplural'] = 'Opdrachten';
$string['newsubmissions'] = 'Ingestuurde opdrachten';
$string['noassignments'] = 'Er zijn nog geen opdrachten';
$string['noattempts'] = 'Er heeft nog niemand zijn opdracht ingestuurd';
$string['notgradedyet'] = 'Nog niet beoordeeld';
$string['notsubmittedyet'] = 'Nog niet ingestuurd';
$string['overwritewarning'] = 'Waarschuwing: als je opnieuw een opdracht instuurt OVERSCHRIJFT deze de huidige ingestuurde opdracht';
$string['preventlate'] = 'Blokkeer te laat insturen';
$string['saveallfeedback'] = 'Bewaar al mijn feedback';
$string['submission'] = 'Ingestuurde opdracht';
$string['submissionfeedback'] = 'Feedback op de ingestuurde opdracht';
$string['submissions'] = 'Ingestuurde opdrachten';
$string['submissionsaved'] = 'Je wijzigingen zijn bewaard';
$string['submitassignment'] = 'Stuur je opdracht in door dit formulier in te vullen';
$string['submitted'] = 'Ingestuurd';
$string['typeoffline'] = 'Off line activiteit';
$string['typeonline'] = 'On line activiteit';
$string['typeuploadsingle'] = 'Upload een bestand';
$string['uploadbadname'] = 'In deze bestandsnaam staan rare tekens, het bestand kon daardoor niet worden gepload';
$string['uploadedfiles'] = 'Ingestuurde bestanden';
$string['uploaderror'] = 'Er is een fout geconstateerd tijdens het opslaan van het bestand op de server';
$string['uploadfailnoupdate'] = 'Het bestand werd prima gepload, maar je bijdrage kon niet worden bijgewerkt!';
$string['uploadfiletoobig'] = 'Helaas is dat bestand te groot (de toegestane grootte is $a bytes)';
$string['uploadnofilefound'] = 'Er werd geen bestand gevonden - weet je zeker dat je er n geselecteerd had om te uploaden?';
$string['uploadnotregistered'] = '\'$a\' werd prima gepload, maar je bijdrage werd niet verwerkt!';
$string['uploadsuccess'] = '\'$a\' met succes gepload  ';
$string['viewfeedback'] = 'Bekijk de cijfers en feedback voor de opdrachten';
$string['viewsubmissions'] = 'Bekijk $a ingestuurde opdrachten';
$string['yoursubmission'] = 'Jouw ingestuurde opdracht';

?>
